@@ -96,7 +96,7 @@ class Cron(ranaModule):
     """remove timeout with a given id"""
     pass
 
-  def modifyTimeout(self,id, newTimeout):
+  def modifyTimeout(self, id, newTimeout):
     """modify the duration of a timeout in progress"""
     pass
 
@@ -110,7 +110,6 @@ class CronGTK(Cron):
     self.nextId = 0
     # cronTab and activeIds should be in sync
     self.cronTab = {"idle":{}, "timeout":{}}
-#    self.info = {}
     self.dataLock = threading.RLock()
 
   def _getID(self):
@@ -133,6 +132,7 @@ class CronGTK(Cron):
     timeoutTuple = (callback, args, timeout, caller, description, realId)
     with self.dataLock:
       self.cronTab['timeout'][id] = timeoutTuple
+    return id
 
   def removeTimeout(self, id):
     """remove timeout with a given id"""
@@ -144,14 +144,14 @@ class CronGTK(Cron):
       else:
         print("cron: can't remove timeout, wrong id: ", id)
 
-  def modifyTimeout(self,id, newTimeout):
+  def modifyTimeout(self, id, newTimeout):
     """modify the duration of a timeout in progress"""
     with self.dataLock:
       if id in self.cronTab['timeout'].keys():
         # load the timeout description
         (callback, args, timeout, caller, description, realId) = self.cronTab['timeout'][id]
         gobject.source_remove(realId) # remove the old timeout
-        realId = gobject.timeout_add(self._doTimeout, newTimeout, id, callback, args) # new timeout
+        realId = gobject.timeout_add(newTimeout, self._doTimeout, id, callback, args) # new timeout
         # update the timeout description
         self.cronTab['timeout'][id] = (callback, args, newTimeout, caller, description, realId)
       else:
@@ -165,7 +165,6 @@ class CronQt(Cron):
     self.nextId = 0
     # cronTab and activeIds should be in sync
     self.cronTab = {"idle":{}, "timeout":{}}
-    #    self.info = {}
     self.dataLock = threading.RLock()
 
   def _getID(self):
@@ -201,6 +200,8 @@ class CronQt(Cron):
       self.cronTab['timeout'][id] = timeoutTuple
     # start the timer
     timer.start(timeout)
+    # return the id
+    return id
 
   def removeTimeout(self, id):
     """remove timeout with a given id"""
